@@ -16,7 +16,7 @@ class MinStack(object):
 
     def pop(self) -> None:
         val = self.stack.pop()
-        if val == self.getMin():
+        if val == self.get_min():
             self.minstack.pop()
 
     def top(self) -> int:
